@@ -116,11 +116,36 @@ def convert_child_to_childport(
 
 
 def convert_argument_to_port(
-    cls, key, registry: StructureRegistry, widget=None, default=None, nullable=False
+    cls,
+    key,
+    registry: StructureRegistry,
+    widget=None,
+    default=None,
+    nullable=False,
+    annotations=[],
 ) -> ArgPortInput:
     """
     Convert a class to an ArgPort
     """
+    if cls.__name__ == "Annotated":
+        print("Annotated")
+        real_type = cls.__args__[0]
+
+        annotations = [
+            registry.get_converter_for_annotation(i.__class__)(i)
+            for i in cls.__metadata__
+        ]
+
+        return convert_argument_to_port(
+            real_type,
+            key,
+            registry,
+            widget=widget,
+            default=default,
+            nullable=nullable,
+            annotations=annotations,
+        )
+
     if cls.__module__ == "typing":
 
         if hasattr(cls, "_name"):
@@ -136,10 +161,11 @@ def convert_argument_to_port(
                     child=child.dict(exclude={"key"}),
                     default=[converter(item) for item in default] if default else None,
                     nullable=nullable,
+                    annotations=annotations,
                 )
 
             if cls._name == "Dict":
-                child, widget, converter = convert_argument_to_port(
+                child, widget, converter = convert_child_to_childport(
                     cls.__args__[1], registry, nullable=False
                 )
                 return ArgPortInput(
@@ -147,12 +173,14 @@ def convert_argument_to_port(
                     widget=widget,
                     key=key,
                     child=child.dict(exclude={"key"}),
-                    default={
-                        key: item in converter(item) for key, item in default.items()
-                    },
+                    default={key: converter(item) for key, item in default.items()},
                     nullable=nullable,
+                    annotations=annotations,
                 )
 
+            if cls._name == "Union":
+                raise NotImplementedError("Union is not supported yet")
+
         if hasattr(cls, "__args__"):
             if cls.__args__[1] == type(None):
                 return convert_argument_to_port(
@@ -173,6 +201,7 @@ def convert_argument_to_port(
                 key=key,
                 default=default,
                 nullable=nullable,
+                annotations=annotations,
             )  # catch bool is subclass of int
             return t
 
@@ -187,6 +216,7 @@ def convert_argument_to_port(
                 key=key,
                 default=default,
                 nullable=nullable,
+                annotations=annotations,
             )
 
         if (
@@ -200,6 +230,7 @@ def convert_argument_to_port(
                 key=key,
                 default=default,
                 nullable=nullable,
+                annotations=annotations,
             )
 
         if (
@@ -213,6 +244,7 @@ def convert_argument_to_port(
                 key=key,
                 default=default,
                 nullable=nullable,
+                annotations=annotations,
             )
 
     identifier = registry.get_identifier_for_structure(cls)
@@ -226,6 +258,7 @@ def convert_argument_to_port(
         key=key,
         default=default_converter(default) if default else None,
         nullable=nullable,
+        annotations=annotations,
     )
 
 
@@ -286,6 +319,8 @@ def convert_return_to_returnport(
             )
         if issubclass(cls, int):
             return ReturnPortInput(kind=PortKindInput.INT, key=key, nullable=nullable)
+        if issubclass(cls, float):
+            return ReturnPortInput(kind=PortKindInput.FLOAT, key=key, nullable=nullable)
         if issubclass(cls, str):
             return ReturnPortInput(
                 kind=PortKindInput.STRING, key=key, nullable=nullable
